/*
 * JBoss, Home of Professional Open Source
 * Copyright 2007, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * (C) 2007,
 * @author JBoss Inc.
 */

package org.jboss.wst.xts;

import javax.transaction.InvalidTransactionException;
import javax.transaction.SystemException;
import javax.transaction.xa.XAException;

/**
 *The interface returned by the transaction manager bridges web sites
 *The downloaded interface allows you to control the visibility range
 *of transactions on the basis of setting it in the state of current or hiding
 * 
 * @author wklaczynski@sabaservice.pl, 2008-01-11
 */
public interface WSTransactionBridge {

    /**
     * Setting up sub transactions in the state management
     * 
     * @throws javax.transaction.xa.XAException
     * @throws javax.transaction.SystemException
     * @throws javax.transaction.InvalidTransactionException
     */
    public void start() throws XAException, SystemException, InvalidTransactionException ;

    /**
     * Setting up sub transactions in the state suspend
     * Menage fault event
     *
     * @throws javax.transaction.xa.XAException
     * @throws javax.transaction.SystemException
     * @throws javax.transaction.InvalidTransactionException
     */
    public void fault() throws XAException, SystemException, InvalidTransactionException ;

    /**
     * Setting up sub transactions in the state suspend
     * 
     * @throws javax.transaction.xa.XAException
     * @throws javax.transaction.SystemException
     * @throws javax.transaction.InvalidTransactionException
     */
    public void stop() throws XAException, SystemException, InvalidTransactionException ;

}
