/*
 * JBoss, Home of Professional Open Source
 * Copyright 2007, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * (C) 2007,
 * @author JBoss Inc.
 */
package org.jboss.wst.xts.common;

import java.io.InputStream;

import java.io.IOException;
import java.util.Properties;

/**
 *
 * @author wklaczynski@sabaservice.pl, 2007-04-30
 */
public class Configuration {

    /**
     * Get properties file name from arjuna.properties
     * @return properties file name
     */
    public static synchronized final String propertiesFile() {
        return _propFile;
    }

    /**
     * Getting the type of transaction is installed on the server JBoss
     * @return transaction type (JTA or JTS)
     */
    public static synchronized final String transactionType() {
        if(_transType == null){
            if("jbossjta-properties.xml".equalsIgnoreCase(_propFile)){
                _transType = Environment.TRANSACTION_TYPE_JTA;
            }else if("jbossjts-properties.xml".equalsIgnoreCase(_propFile)){
                _transType = Environment.TRANSACTION_TYPE_JTS;
            }else{
              _transType = default_transType;
            }
        }
        return _transType;
    }

    /**
     * Getting the value contained in the configuration file xts.properties
     * @param name
     * @return property from name
     */
    public static String getBuildTimeProperty(final String name) {
        if (PROPS == null) {
            return "";
        } else {
            return PROPS.getProperty(name, "");
        }
    }
    private static final Properties PROPS;


    static {
        final InputStream is = Configuration.class.getResourceAsStream("/xts.properties");
        if (is != null) {
            Properties props = new Properties();
            try {
                props.load(is);
            } catch (final IOException ioe) {
                props = null;
            }
            PROPS = props;
        } else {
            PROPS = null;
        }
    }
    private static String _propFile = com.arjuna.ats.arjuna.common.Configuration.getBuildTimeProperty("PROPERTIES_FILE");
    private static String default_transType = getBuildTimeProperty("DEFAULT_TRANSACTION_TYPE");
    private static String _transType = null;
}

