/*
 * JBoss, Home of Professional Open Source
 * Copyright 2007, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * (C) 2007,
 * @author JBoss Inc.
 */
package org.jboss.wst.xts.impl.jta;

import com.arjuna.ats.internal.jta.transaction.arjunacore.jca.XATerminatorImple;
import com.arjuna.wst.Aborted;
import com.arjuna.wst.Durable2PCParticipant;
import com.arjuna.wst.Prepared;
import com.arjuna.wst.ReadOnly;
import com.arjuna.wst.SystemException;
import com.arjuna.wst.Vote;
import com.arjuna.wst.WrongStateException;
import java.io.Serializable;
import org.apache.log4j.Logger;
import javax.transaction.xa.Xid;
import javax.transaction.xa.XAException;
import javax.transaction.xa.XAResource;

/**
 *
 * @author wklaczynski@sabaservice.pl, 2007-04-30
 */
public class BridgeParticipantAT implements Durable2PCParticipant, Serializable {

    private static XATerminatorImple xaTerminatorImple = new XATerminatorImple();

    private static Logger log = Logger.getLogger(BridgeParticipantAT.class);
    private Xid xid;

    /**
     *
     * @param xid
     */
    public BridgeParticipantAT(Xid xid) {
        this.xid = xid;
    }

    /**
     *
     */
    public void commit() {
        try {
            xaTerminatorImple.commit(xid, false);
        } catch (XAException e) {
            log.warn("commit on Xid=" + xid + " failed", e);
        }
    }

    /**
     *
     */
    public void rollback() {
        try {
            xaTerminatorImple.rollback(xid);
        } catch (XAException e) {
            log.warn("rollback on Xid=" + xid + " failed", e);
        }
    }

    /**
     *
     * @throws com.arjuna.wst.SystemException
     */
    public void unknown() throws SystemException {
    }

    /**
     *
     * @throws com.arjuna.wst.SystemException
     */
    public void error() throws SystemException {
    }

    /**
     *
     * @return Prepare result
     * @throws com.arjuna.wst.WrongStateException
     * @throws com.arjuna.wst.SystemException
     */
    public Vote prepare() throws WrongStateException, SystemException {
        try {
            int result = xaTerminatorImple.prepare(xid);
            if (result == XAResource.XA_OK) {
                return new Prepared();
            } else {
                return new ReadOnly();
            }

        } catch (XAException e) {
            return new Aborted();
        }
    }

}

