/*
 * JBoss, Home of Professional Open Source
 * Copyright 2007, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * (C) 2007,
 * @author JBoss Inc.
 */
package org.jboss.wst11.xts;

import javax.transaction.SystemException;
import org.apache.log4j.Logger;
import org.jboss.wst.xts.WSTransactionBridgeManager;
import org.jboss.wst.xts.common.Environment;
import org.jboss.wst.xts.common.xtsPropertyManager;

/**
 *
 * @author wklaczynski@sabaservice.pl, 2007-04-30
 */
public class WSTransactionBridgeManagerFactory {

    private static Logger log = Logger.getLogger(WSTransactionBridgeManagerFactory.class);
    private static WSTransactionBridgeManagerFactory transactionManagerFactory;
    private static WSTransactionBridgeManager wstManagerImpl;

    private WSTransactionBridgeManagerFactory() {
    }

    /**
     *
     * @return Instance of this factory
     */
    public static synchronized WSTransactionBridgeManagerFactory getTransactionManagerFactory() {
        if (transactionManagerFactory == null) {
            transactionManagerFactory = new WSTransactionBridgeManagerFactory();
        }
        return transactionManagerFactory;
    }

    /**
     * 
     * @return Transaction bridge manager
     * @throws javax.transaction.SystemException
     */
    public WSTransactionBridgeManager getWSTransactionBridgeManager() throws SystemException {
        return getWSTJTABridgeManager();
    }

    private WSTransactionBridgeManager getWSTJTABridgeManager() throws SystemException {
        if (wstManagerImpl == null) {
            String type = xtsPropertyManager.getPropertyManager().getProperty(Environment.TRANSACTION_TYPE, Environment.TRANSACTION_TYPE_UNKNOW).toUpperCase().trim();
            if (Environment.TRANSACTION_TYPE_JTA.equals(type)) {
                wstManagerImpl = new org.jboss.wst11.xts.impl.jta.TransactionBridgeManagerImpl();
            } else if (Environment.TRANSACTION_TYPE_JTS.equals(type)) {
                wstManagerImpl = new org.jboss.wst11.xts.impl.jts.TransactionBridgeManagerImpl();
            } else {
                throw new SystemException(String.format("Not suported %s transaction type", type));
            }
        }
        return wstManagerImpl;
    }

}