/*
 * JBoss, Home of Professional Open Source
 * Copyright 2007, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * (C) 2007,
 * @author JBoss Inc.
 */
package org.jboss.wst11.xts;

import java.util.Collections;
import java.util.Set;
import javax.xml.namespace.QName;
import javax.xml.ws.handler.MessageContext;

import javax.xml.ws.handler.soap.SOAPHandler;
import javax.xml.ws.handler.soap.SOAPMessageContext;
import org.apache.log4j.Logger;
import org.jboss.wst.xts.WSTransactionBridge;
import org.jboss.wst.xts.WSTransactionBridgeManager;

/**
 *
 * @author wklaczynski@sabaservice.pl, 2008-01-11
 */
public class WSTransactionBridgeServiceHandler implements SOAPHandler<SOAPMessageContext> {

    private static Logger log = Logger.getLogger(WSTransactionBridgeServiceHandler.class);
    WSTransactionBridgeManagerFactory transactionManagerFactory = WSTransactionBridgeManagerFactory.getTransactionManagerFactory();

    public Set<QName> getHeaders() {
        return Collections.EMPTY_SET;
    }

    public boolean handleMessage(SOAPMessageContext context) {
        Boolean outbound = (Boolean) context.get(MessageContext.MESSAGE_OUTBOUND_PROPERTY);
        if (outbound == null) {
            throw new IllegalStateException("Cannot obtain required property: " + MessageContext.MESSAGE_OUTBOUND_PROPERTY);
        }

        return outbound ? handleOutbound(context) : handleInbound(context);
    }

    public boolean handleFault(SOAPMessageContext context) {
        try {
            WSTransactionBridgeManager transactionManager = transactionManagerFactory.getWSTransactionBridgeManager();
            WSTransactionBridge transactionBridge = transactionManager.getServiceTransactionBridge();
            transactionBridge.fault();
            return true;
        } catch (Exception ex) {
            log.error(ex);
        }
        return false;
    }

    /**
     *
     * @param context
     * @return true if the operation was successful
     */
    protected boolean handleInbound(SOAPMessageContext context) {
        try {
            WSTransactionBridgeManager transactionManager = transactionManagerFactory.getWSTransactionBridgeManager();
            WSTransactionBridge transactionBridge = transactionManager.getServiceTransactionBridge();
            transactionBridge.start();
            return true;
        } catch (Exception ex) {
            log.error(ex);
        }
        return false;
    }

    /**
     *
     * @param context
     * @return true if the operation was successful
     */
    protected boolean handleOutbound(SOAPMessageContext context) {
        try {
            WSTransactionBridgeManager transactionManager = transactionManagerFactory.getWSTransactionBridgeManager();
            WSTransactionBridge transactionBridge = transactionManager.getServiceTransactionBridge();
            transactionBridge.stop();
            return true;
        } catch (Exception ex) {
            log.error(ex);
        }
        return false;
    }

    public void close(MessageContext context) {

    }

}